@@ -1,9 +1,9 @@
 const config = require("./webpack.config.js");
 const path = require("path");
 
-config.entry = { main: "./src/demo/index.js" };
+config.entry = { main: "./src/demo/index.ts" };
 config.output = {
-    filename: "./output.js",
+    filename: "./output.ts",
     path: path.resolve(__dirname),
 };
 config.mode = "development";
